autowisp.database.data_model.provenance.camera_access module — AutoWISP documentation

# autowisp.database.data_model.provenance.camera_access module

## Class Inheritance Diagram

Define the camera access dataset table for the pipeline

class autowisp.database.data_model.provenance.camera_access.CameraAccess(**kwargs)

  Bases: `DataModelBase`

  The table describing the camera access

  camera_id

    A unique identifier of the camera

  id

    A unique identifier for each row.

  observer_id

    A unique identifier for the observer

  timestamp

    When record was last changed